import { Card, message, Form } from 'antd';
import { useEffect, useState } from 'react';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { getSetting, updateSetting } from '@/services/setting';
import SettingRow from '@/components/SettingRow';

const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
const FormItem = Form.Item;
export default (props) => {
  const [data, setData] = useState([]);

  const handleChange = (item, val) => {
    updateSetting(item.settingId, { ...item, content: val })
      .then(() => {
        message.success('修改' + item.title + '成功');
      })
      .catch((err) => {
        message.error(err.message || err);
      });
  };
  useEffect(() => {
    getSetting().then((res) => {
      setData(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
  }, []);
  return (
    <PageHeaderWrapper>
      <Card>
        <Form {...formItemLayout}>
          {data.map((item) => {
            return <FormItem key={item.settingId} label={item.title}>
              <SettingRow value={item} onChange={handleChange} />
            </FormItem>
          })}
        </Form>
      </Card>
    </PageHeaderWrapper>
  );
};
