import React, { useRef,useState } from 'react'
import moment from 'moment';
import { history } from 'umi';
import { DatePicker, Button } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable'
import { getMakeList } from '@/services/application'

const { RangePicker } = DatePicker;

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm') : '';
};

export default (props) => {
  const actionRef = useRef();
  const [applyStart, setStart] = useState()
  const [applyEnd, setEnd] = useState()
  const goDetail = (id) => {
    history.push(`certificateIssuance/issuance.jsx?id=${id}`);
  }
  const handelApplyDateChange = (date, dateStrings) => {
    setStart(dateStrings[0])
    setEnd(dateStrings[1])
  }
  const handleReset = () => {
    setStart()
    setEnd()
  }
  const columns = [
    {
      title: '证件号',
      dataIndex: 'originCardNo',
      key: 'originCardNo',
      search: true,
    },
    {
      title: '犬主',
      dataIndex: 'personName',
      key: 'personName',
      search: true,
    },
    {
      title: '是否企业',
      dataIndex: 'isOrg',
      key: 'isOrg',
      search: true,
      hideInTable:true,
      render: (_, record) => {
        return record.isOrg
          ? '企业':'个人'
      },
      valueType: 'select',
      valueEnum: {
        true: { text: '企业' },
        false: { text: '个人' },
      },
    },
    {
      title: '企业名称',
      dataIndex: 'orgName',
      key: 'orgName',
      search: true,
    },
    {
      title: '手机号',
      dataIndex: 'phone',
      key: 'phone',
      search: true,
    },
    {
      title: '犬名',
      dataIndex: 'petName',
      key: 'petName',
      search: false,
    },
    {
      title: '申领方式',
      dataIndex: 'applyMethod',
      key: 'applyMethod',
      search: true,
      render: (_, record) => {
        return record.applyMethod === 1
          ? '上门自取'
          : record.applyMethod === 2
            ? '快递到家' : ''
      },
      valueType: 'select',
      valueEnum: {
        1: { text: '上门自取' },
        2: { text: '快递到家' },
      },
    },
    {
      title: '申请时间',
      dataIndex: 'createDate',
      key: 'createDate',
      width:160,
      render: (t) => formatterTime(t),
      renderFormItem: (_, record) => <RangePicker placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD'onChange={handelApplyDateChange} />
    },
    {
      title: '制证状态',
      dataIndex: 'status',
      key: 'status',
      render: (_, record) => {
        return record.status === 2
          ? '待发放'
          : record.status === 3
            ? '已发放' : ''
      },
      valueType: 'select',
      valueEnum: {
        2: { text: '待发放' },
        3: { text: '已发放' },
      },
    },
    {
      title: '发放人',
      dataIndex: 'makeUserName',
      key: 'makeUserName',
      search: false,
    },
    {
      title: '发放时间',
      dataIndex: 'makeDate',
      width:160,
      key: 'makeDate',
      render: (t) => t != '-' ? formatterTime(t) : '-',
      search:false
    },
    {
      title: '操作',
      valueType: 'option',
      width: 160,
      render: (_, record) => [
        <Button key={1} style={{ padding: 0 }} type="link"
          onClick={() => goDetail(record.applyId)}
        >
          {record.makeStatus==1?'详情':'发证'}
        </Button>
      ],
    },
  ]


  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={actionRef}
        columns={columns}
        request={getMakeList}
        params={{ applyStart, applyEnd }}
        options={false}
        onReset={handleReset}
        rowKey="applyId"
      />
    </PageHeaderWrapper>
  )
}
